/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package scalapi.jdk.concurrent

import scala.concurrent.Future
import scala.concurrent.Await.result
import scala.concurrent.duration._

/**
 * Helper methods for [[scala.concurrent.Future]].
 */
object Futures {

  /**
   * Converts [[scala.concurrent.Future]] into its value. This method is blocking.
   *
   * @param future [[scala.concurrent.Future]] to converted
   * @param atMost specifies how low method will block until exception is thrown (default is 5 seconds)
   * @tparam T type of [[scala.concurrent.Future]] value
   * @return value of the [[scala.concurrent.Future]]
   */
  def futureToValue[T](future: Future[Any])(implicit atMost: Duration = 5.seconds): T =
    result(future, atMost).asInstanceOf[T]

}
